abacusai.project_feature_group — AbacusAI documentation

# abacusai.project_feature_group

## Classes

`ProjectFeatureGroup` | A feature group along with project specific mappings

## Module Contents

class abacusai.project_feature_group.ProjectFeatureGroup(client, featureGroupId=None, modificationLock=None, name=None, featureGroupSourceType=None, tableName=None, sql=None, datasetId=None, functionSourceCode=None, functionName=None, sourceTables=None, createdAt=None, description=None, sqlError=None, latestVersionOutdated=None, referencedFeatureGroups=None, tags=None, primaryKey=None, updateTimestampKey=None, lookupKeys=None, streamingEnabled=None, incremental=None, mergeConfig=None, samplingConfig=None, cpuSize=None, memory=None, streamingReady=None, featureTags=None, moduleName=None, templateBindings=None, featureExpression=None, useOriginalCsvNames=None, pythonFunctionBindings=None, pythonFunctionName=None, useGpu=None, featureGroupType=None, features={}, duplicateFeatures={}, pointInTimeGroups={}, annotationConfig={}, concatenationConfig={}, indexingConfig={}, codeSource={}, featureGroupTemplate={}, explanation={}, refreshSchedules={}, projectFeatureGroupSchema={}, projectConfig={}, latestFeatureGroupVersion={}, operatorConfig={})

  Bases: `abacusai.feature_group.FeatureGroup`

  A feature group along with project specific mappings

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupId (str) – Unique identifier for this feature group.

    - modificationLock (bool) – If feature group is locked against a change or not.

    - name (str)

    - featureGroupSourceType (str) – The source type of the feature group

    - tableName (str) – Unique table name of this feature group.

    - sql (str) – SQL definition creating this feature group.

    - datasetId (str) – Dataset ID the feature group is sourced from.

    - functionSourceCode (str) – Source definition creating this feature group.

    - functionName (str) – Function name to execute from the source code.

    - sourceTables (list[str]) – Source tables for this feature group.

    - createdAt (str) – Timestamp at which the feature group was created.

    - description (str) – Description of the feature group.

    - sqlError (str) – Error message with this feature group.

    - latestVersionOutdated (bool) – Is latest materialized feature group version outdated.

    - referencedFeatureGroups (list[str]) – Feature groups this feature group is used in.

    - tags (list[str]) – Tags added to this feature group.

    - primaryKey (str) – Primary index feature.

    - updateTimestampKey (str) – Primary timestamp feature.

    - lookupKeys (list[str]) – Additional indexed features for this feature group.

    - streamingEnabled (bool) – If true, the feature group can have data streamed to it.

    - incremental (bool) – If feature group corresponds to an incremental dataset.

    - mergeConfig (dict) – Merge configuration settings for the feature group.

    - samplingConfig (dict) – Sampling configuration for the feature group.

    - cpuSize (str) – CPU size specified for the Python feature group.

    - memory (int) – Memory in GB specified for the Python feature group.

    - streamingReady (bool) – If true, the feature group is ready to receive streaming data.

    - featureTags (dict) – Tags for features in this feature group

    - moduleName (str) – Path to the file with the feature group function.

    - templateBindings (dict) – Config specifying variable names and values to use when resolving a feature group template.

    - featureExpression (str) – If the dataset feature group has custom features, the SQL select expression creating those features.

    - useOriginalCsvNames (bool) – If true, the feature group will use the original column names in the source dataset.

    - pythonFunctionBindings (dict) – Config specifying variable names, types, and values to use when resolving a Python feature group.

    - pythonFunctionName (str) – Name of the Python function the feature group was built from.

    - useGpu (bool) – Whether this feature group is using gpu

    - featureGroupType (str) – Project type when the feature group is used in the context of a project.

    - features (Feature) – List of resolved features.

    - duplicateFeatures (Feature) – List of duplicate features.

    - pointInTimeGroups (PointInTimeGroup) – List of Point In Time Groups.

    - annotationConfig (AnnotationConfig) – Annotation config for this feature

    - latestFeatureGroupVersion (FeatureGroupVersion) – Latest feature group version.

    - concatenationConfig (ConcatenationConfig) – Feature group ID whose data will be concatenated into this feature group.

    - indexingConfig (IndexingConfig) – Indexing config for the feature group for feature store

    - codeSource (CodeSource) – If a Python feature group, information on the source code.

    - featureGroupTemplate (FeatureGroupTemplate) – FeatureGroupTemplate to use when this feature group is attached to a template.

    - explanation (NaturalLanguageExplanation) – Natural language explanation of the feature group

    - refreshSchedules (RefreshSchedule) – List of schedules that determines when the next version of the feature group will be created.

    - projectFeatureGroupSchema (ProjectFeatureGroupSchema) – Project-specific schema for this feature group.

    - projectConfig (ProjectConfig) – Project-specific config for this feature group.

    - operatorConfig (OperatorConfig) – Operator configuration settings for the feature group.

  feature_group_id
  modification_lock
  name
  feature_group_source_type
  table_name
  sql
  dataset_id
  function_source_code
  function_name
  source_tables
  created_at
  description
  sql_error
  latest_version_outdated
  referenced_feature_groups
  tags
  primary_key
  update_timestamp_key
  lookup_keys
  streaming_enabled
  incremental
  merge_config
  sampling_config
  cpu_size
  memory
  streaming_ready
  feature_tags
  module_name
  template_bindings
  feature_expression
  use_original_csv_names
  python_function_bindings
  python_function_name
  use_gpu
  feature_group_type
  features
  duplicate_features
  point_in_time_groups
  annotation_config
  concatenation_config
  indexing_config
  code_source
  feature_group_template
  explanation
  refresh_schedules
  project_feature_group_schema
  project_config
  latest_feature_group_version
  operator_config
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict